pub struct Policy {
pub reason: Reason,
/* private fields */
}Expand description
Minimum-night rule applied before a boarding reservation is accepted.
Fields
reason: ReasonOperational reason the minimum-night rule exists.
Implementations
Sourceimpl Policy
impl Policy
Sourcepub const fn new(nights: StayNights, reason: Reason) -> Self
pub const fn new(nights: StayNights, reason: Reason) -> Self
Creates a minimum-stay policy from validated nights and the policy reason.
Sourcepub const fn nights(&self) -> StayNights
pub const fn nights(&self) -> StayNights
Returns the minimum nights required before this boarding reservation can be accepted.